@@ -14,19 +14,12 @@ class AbsSignalGen(SocIP):
 
     # these must be defined by the subclass
     HAS_MIXER = None # the DAC has a mixer
-    B_DDS = None
-    B_PHASE = None
 
     def _init_config(self, description):
         self.cfg['maxv'] = self.MAXV
 
         assert self.HAS_MIXER is not None
-        assert self.B_DDS is not None
-        assert self.B_PHASE is not None
-
         self.cfg['has_mixer'] = self.HAS_MIXER
-        self.cfg['b_dds'] = self.B_DDS
-        if self.B_PHASE is not None: self.cfg['b_phase'] = self.B_PHASE
 
         super()._init_config(description)
 
@@ -213,6 +206,8 @@ class AbsPulsedSignalGen(AbsSignalGen):
     TPROC_PORT = 's1_axis'
 
     HAS_DDS = True    # Default
+    B_DDS = None
+    B_PHASE = None
 
     def _init_config(self, description):
         if 'GEN_DDS' in description['parameters']:
@@ -220,6 +215,11 @@ class AbsPulsedSignalGen(AbsSignalGen):
         else:
             self.cfg['has_dds'] = self.HAS_DDS
 
+        assert self.B_DDS is not None
+        assert self.B_PHASE is not None
+        self.cfg['b_dds'] = self.B_DDS
+        self.cfg['b_phase'] = self.B_PHASE
+
         super()._init_config(description)
 
     def configure_connections(self, soc):
@@ -251,7 +251,10 @@ class AxisSignalGen(AbsArbSignalGen, AbsPulsedSignalGen):
     """
     bindto = ['user.org:user:axis_signal_gen_v4:1.0',
               'user.org:user:axis_signal_gen_v5:1.0',
-              'user.org:user:axis_signal_gen_v6:1.0']
+              'user.org:user:axis_signal_gen_v6:1.0',
+              'QICK:QICK:axis_signal_gen_v4:1.0',
+              'QICK:QICK:axis_signal_gen_v5:1.0',
+              'QICK:QICK:axis_signal_gen_v6:1.0']
     HAS_MIXER = False
     SAMPS_PER_CLK = 16
     B_DDS = 32
@@ -327,7 +330,8 @@ class AxisSgInt4V1(AbsIntSignalGen):
     """
     Interpolated generator with 16-bit frequency and phase.
     """
-    bindto = ['user.org:user:axis_sg_int4_v1:1.0']
+    bindto = ['user.org:user:axis_sg_int4_v1:1.0',
+              'QICK:QICK:axis_sg_int4_v1:1.0']
     B_DDS = 16
     B_PHASE = 16
 
@@ -335,7 +339,8 @@ class AxisSgInt4V2(AbsIntSignalGen):
     """
     Interpolated generator with 32-bit frequency and phase.
     """
-    bindto = ['user.org:user:axis_sg_int4_v2:1.0']
+    bindto = ['user.org:user:axis_sg_int4_v2:1.0',
+              'QICK:QICK:axis_sg_int4_v2:1.0']
     B_DDS = 32
     B_PHASE = 32
 
@@ -461,7 +466,8 @@ class AxisSgMux4V1(AbsPulsedSignalGen):
 
     AXIS Signal Generator with 4 muxed outputs.
     """
-    bindto = ['user.org:user:axis_sg_mux4_v1:1.0']
+    bindto = ['user.org:user:axis_sg_mux4_v1:1.0',
+              'QICK:QICK:axis_sg_mux4_v1:1.0']
     HAS_MIXER = True
     B_DDS = 16
     N_TONES = 4
@@ -474,7 +480,8 @@ class AxisSgMux4V2(AbsMuxSignalGen):
 
     AXIS Signal Generator with 4 muxed outputs.
     """
-    bindto = ['user.org:user:axis_sg_mux4_v2:1.0']
+    bindto = ['user.org:user:axis_sg_mux4_v2:1.0',
+              'QICK:QICK:axis_sg_mux4_v2:1.0']
     HAS_MIXER = True
     B_DDS = 32
     N_TONES = 4
@@ -484,7 +491,8 @@ class AxisSgMux4V2(AbsMuxSignalGen):
 class AxisSgMux4V3(AxisSgMux4V2):
     """AxisSgMux4V3: no digital mixer, but otherwise behaves identically to AxisSgMux4V2.
     """
-    bindto = ['user.org:user:axis_sg_mux4_v3:1.0']
+    bindto = ['user.org:user:axis_sg_mux4_v3:1.0',
+              'QICK:QICK:axis_sg_mux4_v3:1.0']
     HAS_MIXER = False
 
 class AxisSgMux8V1(AbsMuxSignalGen):
@@ -493,7 +501,8 @@ class AxisSgMux8V1(AbsMuxSignalGen):
 
     AXIS Signal Generator with 8 muxed outputs, fullspeed (no DAC mixer).
     """
-    bindto = ['user.org:user:axis_sg_mux8_v1:1.0']
+    bindto = ['user.org:user:axis_sg_mux8_v1:1.0',
+              'QICK:QICK:axis_sg_mux8_v1:1.0']
     HAS_MIXER = False
     B_DDS = 32
     N_TONES = 8
@@ -507,7 +516,8 @@ class AxisSgMixMux8V1(AbsMuxSignalGen):
 
     AXIS Signal Generator with 8 muxed outputs, using DAC mixer.
     """
-    bindto = ['user.org:user:axis_sg_mixmux8_v1:1.0']
+    bindto = ['user.org:user:axis_sg_mixmux8_v1:1.0',
+              'QICK:QICK:axis_sg_mixmux8_v1:1.0']
     HAS_MIXER = True
     B_DDS = 32
     N_TONES = 8
@@ -522,7 +532,8 @@ class AxisConstantIQ(AbsSignalGen):
     # REAL_REG : 16-bit.
     # IMAG_REG : 16-bit.
     # WE_REG   : 1-bit. Update registers.
-    bindto = ['user.org:user:axis_constant_iq:1.0']
+    bindto = ['user.org:user:axis_constant_iq:1.0',
+              'QICK:QICK:axis_constant_iq:1.0']
     HAS_MIXER = True
 
     def _init_config(self, description):
